@@ -1,7 +1,6 @@
 package Sidef::Object::Enumerator {
 
-    use utf8;
-    use 5.016;
+    use 5.014;
     ##use overload q{""} => \&to_a;
 
     sub new {
@@ -55,7 +54,17 @@ package Sidef::Object::Enumerator {
     sub each {
         my ($self, $block) = @_;
 
-        $self->{block}->run($block);
+        $self->{block}->run(
+            Sidef::Types::Block::Block->new(
+                code => sub {
+                    @_
+                      ? @_ == 1
+                          ? $block->run($_[0])
+                          : do { $block->run($_) for @_ }
+                      : ();
+                },
+            )
+        );
 
         $self;
     }
@@ -75,8 +84,6 @@ package Sidef::Object::Enumerator {
         Sidef::Types::Array::Array->new(\@arr);
     }
 
-    *collect = \&map;
-
     sub grep {
         my ($self, $block) = @_;
 
