@@ -1,10 +1,7 @@
 package Sidef::Time::Time {
 
     use 5.014;
-    use parent qw(
-      Sidef::Object::Object
-      Sidef::Convert::Convert
-      );
+    use parent qw(Sidef::Object::Object);
 
     use overload
       q{""}   => \&get_value,
