@@ -1,7 +1,7 @@
 package Sidef::Types::Glob::FileHandle {
 
     use utf8;
-    use 5.016;
+    use 5.014;
 
     use parent qw(
       Sidef::Object::Object
@@ -29,8 +29,6 @@ package Sidef::Types::Glob::FileHandle {
         $_[0]{parent};
     }
 
-    *file = \&parent;
-
     sub is_on_tty {
         (-t $_[0]{fh}) ? (Sidef::Types::Bool::Bool::TRUE) : (Sidef::Types::Bool::Bool::FALSE);
     }
@@ -139,7 +137,7 @@ package Sidef::Types::Glob::FileHandle {
             do {
                 local $/;
                 CORE::readline($self->{fh});
-            }
+              }
         );
     }
 
@@ -217,8 +215,6 @@ package Sidef::Types::Glob::FileHandle {
         Sidef::Types::Array::Array->new(\@array);
     }
 
-    *collect = \&map;
-
     sub words {
         my ($self) = @_;
         Sidef::Types::Array::Array->new(
@@ -227,7 +223,7 @@ package Sidef::Types::Glob::FileHandle {
                  map    { Sidef::Types::String::String->new($_) }
                    grep { $_ ne '' }
                    split(' ', $_)
-             } CORE::readline($self->{fh})
+               } CORE::readline($self->{fh})
             ]
         );
     }
@@ -239,7 +235,7 @@ package Sidef::Types::Glob::FileHandle {
              map { Sidef::Types::String::String->new($_) } do {
                  local $/;
                  split(//, scalar CORE::readline($self->{fh}));
-             }
+               }
             ]
         );
     }
@@ -276,26 +272,27 @@ package Sidef::Types::Glob::FileHandle {
 
     sub tell {
         my ($self) = @_;
-        Sidef::Types::Number::Number->new(CORE::tell($self->{fh}));
+        Sidef::Types::Number::Number->new(tell($self->{fh}));
     }
 
     sub seek {
         my ($self, $pos, $whence) = @_;
-        CORE::seek($self->{fh}, $pos, $whence)
+        seek($self->{fh}, $pos, $whence,)
           ? (Sidef::Types::Bool::Bool::TRUE)
           : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub sysseek {
         my ($self, $pos, $whence) = @_;
-        CORE::sysseek($self->{fh}, $pos, $whence)
+
+        sysseek($self->{fh}, $pos, $whence,)
           ? (Sidef::Types::Bool::Bool::TRUE)
           : (Sidef::Types::Bool::Bool::FALSE);
     }
 
     sub fileno {
         my ($self) = @_;
-        Sidef::Types::Number::Number->new(CORE::fileno($self->{fh}));
+        Sidef::Types::Number::Number->new(fileno($self->{fh}));
     }
 
     sub lock {
@@ -383,9 +380,9 @@ package Sidef::Types::Glob::FileHandle {
     {
         no strict 'refs';
         *{__PACKAGE__ . '::' . '>>'} = \&read_to;
-        *{__PACKAGE__ . '::' . '»'}  = \&read_to;
+        *{__PACKAGE__ . '::' . '»'} = \&read_to;
         *{__PACKAGE__ . '::' . '<<'} = \&write_from;
-        *{__PACKAGE__ . '::' . '«'}  = \&write_from;
+        *{__PACKAGE__ . '::' . '«'} = \&write_from;
     }
 
 };
