@@ -3,10 +3,7 @@ package Sidef::Types::String::String {
     use utf8;
     use 5.014;
 
-    use parent qw(
-      Sidef::Object::Object
-      Sidef::Convert::Convert
-      );
+    use parent qw(Sidef::Object::Object);
 
     use overload
       q{bool} => \&get_value,
@@ -447,7 +444,7 @@ package Sidef::Types::String::String {
     }
 
     sub _string_or_regex {
-        my ($self, $obj) = @_;
+        my ($obj) = @_;
 
         if (ref($obj) eq 'Sidef::Types::Regex::Regex') {
             return $obj->{regex};
@@ -462,7 +459,7 @@ package Sidef::Types::String::String {
         ref($str) eq 'Sidef::Types::Block::Block'
           && return $self->esub($regex, $str);
 
-        my $search = $self->_string_or_regex($regex);
+        my $search = _string_or_regex($regex);
         my $value  = "$str";
 
         $self->new($$self =~ s{$search}{$value}r);
@@ -476,7 +473,7 @@ package Sidef::Types::String::String {
         ref($str) eq 'Sidef::Types::Block::Block'
           && return $self->gesub($regex, $str);
 
-        my $search = $self->_string_or_regex($regex);
+        my $search = _string_or_regex($regex);
         my $value  = "$str";
         $self->new($$self =~ s{$search}{$value}gr);
     }
@@ -491,7 +488,7 @@ package Sidef::Types::String::String {
     sub esub {
         my ($self, $regex, $code) = @_;
 
-        my $search = $self->_string_or_regex($regex);
+        my $search = _string_or_regex($regex);
 
         if (ref($code) eq 'Sidef::Types::Block::Block') {
             return $self->new($$self =~ s{$search}{$code->run(_get_captures($$self))}er);
@@ -503,7 +500,7 @@ package Sidef::Types::String::String {
     sub gesub {
         my ($self, $regex, $code) = @_;
 
-        my $search = $self->_string_or_regex($regex);
+        my $search = _string_or_regex($regex);
 
         if (ref($code) eq 'Sidef::Types::Block::Block') {
             my $value = $$self;
@@ -562,7 +559,7 @@ package Sidef::Types::String::String {
                                                [map { bless(\$_, __PACKAGE__) } unpack '(a' . CORE::int($sep) . ')*', $$self]);
         }
 
-        $sep = $self->_string_or_regex($sep);
+        $sep = _string_or_regex($sep);
         Sidef::Types::Array::Array->new([map { bless(\$_, __PACKAGE__) } split(/$sep/, $$self, $size)]);
     }
 
